@@ -741,7 +741,7 @@
 	}
 	# some checks
 	if(is.na(rseed[1])){
-		sseed = as.integer(runif(1,0,as.integer(Sys.time())))
+    sseed = NA
 	} else{
 		if(length(rseed) != m.sim) sseed = as.integer(rseed[1]) else sseed = rseed[1:m.sim]
 	}
@@ -899,7 +899,7 @@
 		}
 	}
 	if(is.na(rseed[1])){
-		sseed = as.integer(runif(1,0,as.integer(Sys.time())))
+    sseed = NA
 	} else{
 		if(length(rseed) != m.sim) sseed = as.integer(rseed[1]) else sseed = rseed[1:m.sim]
 	}
@@ -1098,7 +1098,7 @@
 	}
 	# some checks
 	if(is.na(rseed[1])){
-		sseed = as.integer(runif(1,0,as.integer(Sys.time())))
+    sseed = NA
 	} else{
 		if(length(rseed) != m.sim) sseed = as.integer(rseed[1]) else sseed = rseed[1:m.sim]
 	}
@@ -1258,7 +1258,7 @@
 	}
 	# some checks
 	if(is.na(rseed[1])){
-		sseed = as.integer(runif(1,0,as.integer(Sys.time())))
+    sseed = NA
 	} else{
 		if(length(rseed) != m.sim) sseed = as.integer(rseed[1]) else sseed = rseed[1:m.sim]
 	}
